# Python for People Analytics

## Documentation
https://py4pa.readthedocs.io/en/latest/py4pa.html


## Installation

Download and install the package on your machine:
```
pip install py4pa
```

If you need to bypass SSL verification on your machine (if you are behind a proxy for example), you can use the following install command:
```
pip install py4pa --trusted-host pypi.org --trusted-host files.pythonhosted.org
```

Import the package into your Python script:
```
import py4pa
# or
from py4pa import [arm]
```

